# Accessibility Statement for OU Book Theme

The Open University is committed to making its websites and mobile applications accessible, in accordance with the Public Sector Bodies (Websites and Mobile Applications) (No. 2) Accessibility Regulations 2018.

This accessibility statement applies to the OU Book Theme.

We want as many people as possible to be able to use our websites and mobile apps, and accessibility is an essential part of our mission. On our [Accessibility Hub](https://about.open.ac.uk/strategy-and-policies/policies-and-statements/website-accessibility-open-university), you'll find everything you need to answer any questions you have about accessibility, whether you're a student or a member of staff.

To adapt the content to your needs or preferences you should be able to:

* Change colours, contrasts levels and fonts.
* Resize text up to 200% without impact on the functionality of the website.
* Zoom in up to 400% without loss of information or functionality.
* Navigate the website using just a keyboard.

  * tab to ‘Skip to content’ links at the top of the page to jump over repetitive information to the main content.
  * tab through the content; the current location will be indicated by a clear visual change.
  * control the embedded media player to play audio and video materials.

* Use a screen reader (e.g. JAWs, NVDA) to:

  * listen to the content of web pages and use any functionality on the page.
  * list the headings and subheadings in the page and then jump to their location on the page.
  * bring up a list of meaningful links on the page.

* Use transcripts or closed captions with most audio and video materials.
* Download learning materials in alternative formats (e.g. Word document, PDF, ePub, Kindle eBook).
* If you have a print disability we provide [SensusAccess](https://www.open.ac.uk/libraryservices/subsites/sensusaccess/convert-a-file-with-sensus-access) to students, which is an automated service that converts files from one format to another, for example, PDF to text, audio, Word or Braille.
* [AbilityNet](https://mcmw.abilitynet.org.uk/) also provides advice on making your device easier to use if you have a disability.

## Compliance status

This website is fully compliant with the Web Content Accessibility Guidelines version 2.2 AA standard.

## Preparation of this accessibility statement

This statement was prepared on 26.06.2023.

The statement was last reviewed on 26.06.2023.

The website was last tested on 26.06.2023.

The website was tested using a combination of automatic accessibility checking tools as part of the website's standard development process.

## Feedback and contact information

If you find that a certain section of our website is not accessible and you can’t get access to the information that you need please use the Open [University Accessibility Feedback Form](http://forms.office.com/Pages/ResponsePage.aspx?id=VdQuDq-WAEG-06jl_ZgWhZZerd7KTdxLs5rJWOBff-tUMTNNTTMyUzhBOEYxTEw2ODUyM0pWOUtPWS4u) to request support and we will ensure that you are provided with the information you require. You will need to provide your contact details and Personal Identifier if you are a student so we can get back to you. You should expect to hear back from us within 5 working days.

The OU is very experienced in meeting accessibility needs for our students. In many cases we are able to provide module and other study support materials in alternative formats for students who indicate a need for this when completing a [Disability Support Form](https://msds.open.ac.uk/signon/SAMSDefault/SAMS001_Default.aspx?URL=https://help.open.ac.uk/disability-support-form).

In addition, some module materials are available in different formats and can be downloaded from module websites. Students can contact their [Student Support Team](https://www.open.ac.uk/contact/) for advice.

If you are a student, or someone who has had contact with the University before, and have a complaint about the accessibility of our websites, you should raise a complaint via the [complaints and appeals process](https://help.open.ac.uk/browse/policies-and-complaints/complaints-and-appeals).

## Enforcement procedure

The Equality and Human Rights Commission (EHRC) is responsible for enforcing the Public Sector Bodies (Websites and Mobile Applications) (No. 2) Accessibility Regulations 2018 (the ‘accessibility regulations’).

If you are based in the UK, and you’re not happy with how we respond to your complaint, contact the [Equality Advisory and Support Service (EASS)](https://www.equalityadvisoryservice.com/). If you are based in Northern Ireland, and you’re not happy with how we respond to your complaint, contact the [Equalities Commission for Northern Ireland (ECNI)](https://www.equalityni.org/Home).
